@@ -66,6 +66,14 @@ class Slack:
             text=text,
             ts=timestamp,
             **kwargs,
+        ).data
+
+    def post_message(self, channel, text, **kwargs):
+        """Alias for chat_post_message."""
+        return self.chat_post_message(
+            channel=channel,
+            text=text,
+            **kwargs
         )
 
     #
