@@ -354,7 +354,11 @@ class Update:
             google_group_slack_user_ids = []
             for email in google_group_members:
                 if email in users:
-                    google_group_slack_user_ids.append(users[email]["id"])
+                    user = users[email]
+                    user_id = user["id"]
+                    # skip deleted and single-channel guest users
+                    if user["active"] and email.endswith("@broadinstitute.org"):
+                        google_group_slack_user_ids.append(user_id)
             google_group_slack_user_ids = sorted(set(google_group_slack_user_ids))
 
             # assemble group users into group members
